@@ -3,7 +3,7 @@ package FFI::Build::File::C;
 use strict;
 use warnings;
 use 5.008004;
-use base qw( FFI::Build::File::Base );
+use parent qw( FFI::Build::File::Base );
 use constant default_suffix => '.c';
 use constant default_encoding => ':utf8';
 use Capture::Tiny ();
@@ -11,7 +11,7 @@ use File::Path ();
 use FFI::Build::File::Object;
 
 # ABSTRACT: Class to track C source file in FFI::Build
-our $VERSION = '1.41_01'; # TRIAL VERSION
+our $VERSION = '1.45_01'; # TRIAL VERSION
 
 
 sub accept_suffix
@@ -186,7 +186,7 @@ FFI::Build::File::C - Class to track C source file in FFI::Build
 
 =head1 VERSION
 
-version 1.41_01
+version 1.45_01
 
 =head1 SYNOPSIS
 
@@ -238,6 +238,8 @@ Eric Brine (IKEGAMI)
 
 szTheory
 
+José Joaquín Atria (JJATRIA)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2015,2016,2017,2018,2019,2020 by Graham Ollis.
