@@ -3,12 +3,12 @@ package FFI::Build::File::CXX;
 use strict;
 use warnings;
 use 5.008004;
-use base qw( FFI::Build::File::C );
+use parent qw( FFI::Build::File::C );
 use constant default_suffix => '.cxx';
 use constant default_encoding => ':utf8';
 
 # ABSTRACT: Class to track C source file in FFI::Build
-our $VERSION = '1.41_01'; # TRIAL VERSION
+our $VERSION = '1.45_01'; # TRIAL VERSION
 
 
 sub accept_suffix
@@ -42,7 +42,7 @@ FFI::Build::File::CXX - Class to track C source file in FFI::Build
 
 =head1 VERSION
 
-version 1.41_01
+version 1.45_01
 
 =head1 SYNOPSIS
 
@@ -94,6 +94,8 @@ Eric Brine (IKEGAMI)
 
 szTheory
 
+José Joaquín Atria (JJATRIA)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2015,2016,2017,2018,2019,2020 by Graham Ollis.
