@@ -8,7 +8,7 @@ use FFI::Platypus::Function;
 use FFI::Platypus::Type;
 
 # ABSTRACT: Write Perl bindings to non-Perl libraries with FFI. No XS required.
-our $VERSION = '1.41_01'; # TRIAL VERSION
+our $VERSION = '1.45_01'; # TRIAL VERSION
 
 # Platypus-Man,
 # Platypus-Man,
@@ -585,7 +585,7 @@ FFI::Platypus - Write Perl bindings to non-Perl libraries with FFI. No XS requir
 
 =head1 VERSION
 
-version 1.41_01
+version 1.45_01
 
 =head1 SYNOPSIS
 
@@ -717,6 +717,8 @@ the L<lib|/lib> attribute.
 
 =item api
 
+[version 0.91]
+
 Sets the API level.  Legal values are
 
 =over
@@ -735,6 +737,27 @@ version 1.00 will trigger a (noisy) warning.
 All new code should be written with this set to 1!  The Platypus documentation
 assumes this api level is set.
 
+=item C<2>
+
+Enable version 2 API, which is currently experimental.  Using API level 2 prior
+to Platypus version 2.00 will trigger a (noisy) warning.
+
+API version 2 is identical to version 1, except:
+
+=over 4
+
+=item Pointer functions that return C<NULL> will return C<undef> instead of empty list
+
+This fixes a long standing design bug in Platypus.
+
+=item Array references may be passed to pointer argument types
+
+This replicates the behavior of array argument types with no size.  So the types C<sint8*> and C<sint8[]>
+behave identically when an array reference is passed in.  They differ in that, as before, you can
+pass a scalar reference into type C<sint8*>.
+
+=back
+
 =back
 
 =item lib
@@ -1406,7 +1429,7 @@ L<FFI::Platypus::Memory> module.
    });
  }
  
- # now we can actually use our My::UnixTime class
+ # now we can actually use our Unix::TimeStruct class
  my $time = Unix::TimeStruct->localtime;
  printf "time is %d:%d:%d %s\n",
    $time->tm_hour,
@@ -2507,6 +2530,8 @@ Eric Brine (IKEGAMI)
 
 szTheory
 
+José Joaquín Atria (JJATRIA)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2015,2016,2017,2018,2019,2020 by Graham Ollis.
