@@ -4,13 +4,13 @@ use strict;
 use warnings;
 use 5.008004;
 use FFI::Platypus;
-use base qw( Exporter );
+use Exporter qw( import );
 
 our @EXPORT = qw( scalar_to_buffer buffer_to_scalar );
 our @EXPORT_OK = qw ( scalar_to_pointer grow set_used_length window );
 
 # ABSTRACT: Convert scalars to C buffers
-our $VERSION = '1.41_01'; # TRIAL VERSION
+our $VERSION = '1.45_01'; # TRIAL VERSION
 
 
 use constant _incantation =>
@@ -50,7 +50,7 @@ FFI::Platypus::Buffer - Convert scalars to C buffers
 
 =head1 VERSION
 
-version 1.41_01
+version 1.45_01
 
 =head1 SYNOPSIS
 
@@ -106,7 +106,7 @@ copying the buffer instead.  For example:
  use FFI::Platypus::Memory qw( malloc memcpy free )
  
  my($ptr, $size) = scalar_to_buffer $string;
- c_function_thaat_does_not_keep_ptr( $ptr, $size); # okay
+ c_function_that_does_not_keep_ptr( $ptr, $size); # okay
  
  my($ptr, $size) = scalar_to_buffer $string;
  my $ptr_copy = malloc($size);
@@ -350,6 +350,8 @@ Eric Brine (IKEGAMI)
 
 szTheory
 
+José Joaquín Atria (JJATRIA)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2015,2016,2017,2018,2019,2020 by Graham Ollis.
