@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.008004;
 use FFI::Platypus;
-use base qw( Exporter );
+use Exporter qw( import );
 
 require FFI::Platypus;
 _init();
@@ -12,7 +12,7 @@ _init();
 our @EXPORT = grep /^FFI_PL/, keys %FFI::Platypus::Internal::;
 
 # ABSTRACT: For internal use only
-our $VERSION = '1.41_01'; # TRIAL VERSION
+our $VERSION = '1.45_01'; # TRIAL VERSION
 
 
 1;
@@ -29,7 +29,7 @@ FFI::Platypus::Internal - For internal use only
 
 =head1 VERSION
 
-version 1.41_01
+version 1.45_01
 
 =head1 SYNOPSIS
 
@@ -80,6 +80,8 @@ Eric Brine (IKEGAMI)
 
 szTheory
 
+José Joaquín Atria (JJATRIA)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2015,2016,2017,2018,2019,2020 by Graham Ollis.
