@@ -4,10 +4,10 @@ use strict;
 use warnings;
 use 5.008004;
 use Carp qw( croak );
-use base qw( FFI::Platypus::TypeParser );
+use parent qw( FFI::Platypus::TypeParser );
 
 # ABSTRACT: FFI Type Parser Version Zero
-our $VERSION = '1.41_01'; # TRIAL VERSION
+our $VERSION = '1.45_01'; # TRIAL VERSION
 
 
 our @CARP_NOT = qw( FFI::Platypus FFI::Platypus::TypeParser );
@@ -165,7 +165,7 @@ FFI::Platypus::TypeParser::Version0 - FFI Type Parser Version Zero
 
 =head1 VERSION
 
-version 1.41_01
+version 1.45_01
 
 =head1 SYNOPSIS
 
@@ -269,6 +269,8 @@ Eric Brine (IKEGAMI)
 
 szTheory
 
+José Joaquín Atria (JJATRIA)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2015,2016,2017,2018,2019,2020 by Graham Ollis.
